// Funciones de utilidad
const formatCurrency = (number) => {
    return new Intl.NumberFormat('es-AR', {
        style: 'currency',
        currency: 'ARS'
    }).format(number);
};

const formatDate = (date) => {
    return date.toLocaleDateString('es-AR');
};

const generateSimulationNumber = () => {
    return new Date().getTime().toString().slice(-6);
};

// Función principal
document.addEventListener('DOMContentLoaded', function() {
    // Referencias a elementos del DOM
    const loanForm = document.getElementById('loanForm');
    const resultsDiv = document.getElementById('results');
    const confirmLoanBtn = document.getElementById('confirmLoan');

    // Establecer valores por defecto
    document.getElementById('term').value = '52';
    document.getElementById('rate').value = '200';

    // Calcular préstamo
    const calculateLoan = (amount, initialPayment, term, rate) => {
        const finalAmount = amount - initialPayment;
        const weeklyRate = (rate / 100) / 52;
        const weeklyPayment = finalAmount * (weeklyRate * Math.pow(1 + weeklyRate, term)) / 
                             (Math.pow(1 + weeklyRate, term) - 1);
        
        const totalPayment = weeklyPayment * term;
        const totalInterest = totalPayment - finalAmount;

        const amortizationSchedule = [];
        let balance = finalAmount;
        let currentDate = new Date();
        
        for (let week = 1; week <= term; week++) {
            const interestPayment = balance * weeklyRate;
            const principalPayment = weeklyPayment - interestPayment;
            balance -= principalPayment;
            currentDate.setDate(currentDate.getDate() + 7);

            amortizationSchedule.push({
                week,
                date: new Date(currentDate),
                payment: weeklyPayment,
                principal: principalPayment,
                interest: interestPayment,
                balance: Math.max(0, balance)
            });
        }

        return {
            finalAmount,
            weeklyPayment,
            totalPayment,
            totalInterest,
            amortizationSchedule
        };
    };

        // Generar tabla de amortización
        const tableBody = document.getElementById('amortizationTableBody');
        tableBody.innerHTML = '';

        results.amortizationSchedule.forEach(row => {
            const tr = document.createElement('tr');
            tr.innerHTML = `
                <td class="px-4 py-2 text-sm text-gray-900">${row.week}</td>
                <td class="px-4 py-2 text-sm text-gray-900">${formatCurrency(row.payment)}</td>
                <td class="px-4 py-2 text-sm text-gray-900">${formatCurrency(row.principal)}</td>
                <td class="px-4 py-2 text-sm text-gray-900">${formatCurrency(row.interest)}</td>
                <td class="px-4 py-2 text-sm text-gray-900">${formatCurrency(row.balance)}</td>
            `;
            tableBody.appendChild(tr);
        });

        // Mostrar sección de resultados con animación
        resultsDiv.classList.remove('hidden');
        resultsDiv.classList.add('fade-in');
    };

    // Event Listeners
    loanForm.addEventListener('submit', function(e) {
        e.preventDefault();

        // Obtener valores del formulario
        const amount = parseFloat(document.getElementById('amount').value) || 0;
        const term = parseInt(document.getElementById('term').value) || 52;
        const rate = parseFloat(document.getElementById('rate').value) || 200;

        // Validar entrada
        if (amount <= 0) {
            alert('Por favor, ingrese un monto válido mayor a 0.');
            return;
        }

        // Calcular y mostrar resultados
        const results = calculateLoan(amount, term, rate);
        displayResults(results);
    });

    // Toggle tabla de amortización
    toggleTableBtn.addEventListener('click', function() {
        const isHidden = amortizationTable.classList.contains('hidden');
        
        if (isHidden) {
            amortizationTable.classList.remove('hidden');
            toggleTableBtn.innerHTML = '<i class="fas fa-chevron-up"></i>';
        } else {
            amortizationTable.classList.add('hidden');
            toggleTableBtn.innerHTML = '<i class="fas fa-chevron-down"></i>';
        }
    });

    // Confirmar préstamo
    confirmLoanBtn.addEventListener('click', function() {
        const amount = parseFloat(document.getElementById('amount').value);
        const term = parseInt(document.getElementById('term').value);
        const rate = parseFloat(document.getElementById('rate').value);

        // Aquí puedes agregar la lógica para enviar los datos al servidor
        // Por ahora, solo mostraremos un mensaje de confirmación
        const confirmed = confirm(`¿Desea confirmar el préstamo con los siguientes datos?\n\n` +
            `Monto: ${formatCurrency(amount)}\n` +
            `Plazo: ${term} semanas\n` +
            `Tasa: ${rate}% anual`);

        if (confirmed) {
            // Aquí puedes redirigir al usuario al sistema de créditos existente
            alert('Préstamo confirmado. Será redirigido al sistema de créditos.');
            // window.location.href = 'URL_DEL_SISTEMA_DE_CREDITOS';
        }
    });
});