<?php
ini_set('display_errors', 1);
ini_set('display_startup_errors', 1);
error_reporting(E_ALL);

file_put_contents("log_etapas.txt", "0 - Inicio\n", FILE_APPEND);

require_once 'config.php';
require_once 'db.php';

$input_raw = file_get_contents('php://input');
file_put_contents("log_json.txt", $input_raw);
$input = json_decode($input_raw, true);
file_put_contents("log_etapas.txt", "1 - JSON decodificado\n", FILE_APPEND);

if (!$input) {
    file_put_contents("log_etapas.txt", "2 - JSON inválido\n", FILE_APPEND);
    http_response_code(400);
    echo "Datos inválidos";
    exit;
}

try {
    $db = Database::getInstance()->getConnection();
    $db->beginTransaction();
    file_put_contents("log_etapas.txt", "3 - Conexión y transacción iniciada\n", FILE_APPEND);

    // Verificar o crear cliente POR NOMBRE Y CONTACTO
    $stmt = $db->prepare("SELECT id FROM customers WHERE name = ? AND contact = ?");
    $stmt->execute([$input['nombre'], $input['contacto']]);
    $cliente = $stmt->fetch();

    if ($cliente) {
        $clienteId = $cliente['id'];
        file_put_contents("log_etapas.txt", "4 - Cliente existente ID: $clienteId\n", FILE_APPEND);

        // Actualizar DNI si es diferente o está vacío
        $stmtDni = $db->prepare("SELECT dni FROM customers WHERE id = ?");
        $stmtDni->execute([$clienteId]);
        $dniExistente = $stmtDni->fetchColumn();

        if (!$dniExistente || $dniExistente !== $input['dni']) {
            $stmtActualizar = $db->prepare("UPDATE customers SET dni = ? WHERE id = ?");
            $stmtActualizar->execute([$input['dni'], $clienteId]);
            file_put_contents("log_etapas.txt", "4B - DNI actualizado a {$input['dni']}\n", FILE_APPEND);
        }

    } else {
        $stmt = $db->prepare("INSERT INTO customers (name, contact, dni) VALUES (?, ?, ?)");
        $stmt->execute([$input['nombre'], $input['contacto'], $input['dni']]);
        $clienteId = $db->lastInsertId();
        file_put_contents("log_etapas.txt", "4 - Cliente nuevo creado ID: $clienteId\n", FILE_APPEND);
    }

    // Crear crédito
    $stmt = $db->prepare("INSERT INTO credits (customer_id, product, total_amount, num_installments, outstanding_balance, start_date)
                          VALUES (?, ?, ?, ?, ?, NOW())");
    $stmt->execute([
        $clienteId,
        $input['producto'],
        $input['total'],
        $input['cuotas'],
        $input['total']
    ]);
    $creditoId = $db->lastInsertId();
    file_put_contents("log_etapas.txt", "5 - Crédito creado ID: $creditoId\n", FILE_APPEND);

    // Insertar cuotas
    $stmt = $db->prepare("INSERT INTO installments (credit_id, installment_number, due_date, amount, amount_paid, status) 
                          VALUES (?, ?, ?, ?, ?, 'pendiente')");

    foreach ($input['cuotasDetalle'] as $cuota) {
        $fecha = DateTime::createFromFormat('d/m/Y', $cuota['fecha']);
        if (!$fecha) {
            $fecha = DateTime::createFromFormat('Y-m-d', $cuota['fecha']);
        }

        if (!$fecha) {
            $mensajeFecha = "Fecha inválida en cuota número {$cuota['numero']}: '{$cuota['fecha']}'";
            file_put_contents("log_etapas.txt", "ERROR: $mensajeFecha\n", FILE_APPEND);
            continue;
        }

        $fechaFormateada = $fecha->format('Y-m-d');

        $stmt->execute([
            $creditoId,
            $cuota['numero'],
            $fechaFormateada,
            $cuota['monto'],
            0.00
        ]);
    }

    file_put_contents("log_etapas.txt", "7 - Todas las cuotas insertadas\n", FILE_APPEND);

    $db->commit();
    file_put_contents("log_etapas.txt", "8 - Commit exitoso\n", FILE_APPEND);
    echo "OK";

} catch (Exception $e) {
    $db->rollBack();
    $mensaje = "Error al crear crédito desde simulación: " . $e->getMessage();
    file_put_contents("log_etapas.txt", "ERROR: $mensaje\n", FILE_APPEND);
    error_log($mensaje);
    http_response_code(500);
    echo "Error interno";
}
?>