<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$creditId = isset($_GET['id']) ? (int)$_GET['id'] : null;

if (!$creditId) {
    header('Location: index.php');
    exit;
}

try {
    $db = Database::getInstance()->getConnection();

    // Si se confirma la eliminación
    if (isset($_POST['confirm_delete']) && $_POST['confirm_delete'] === 'yes') {
        $db->beginTransaction();

        try {
            // Verificar si el crédito existe
            $stmt = $db->prepare("SELECT c.*, cu.name as customer_name FROM credits c JOIN customers cu ON c.customer_id = cu.id WHERE c.id = ?");
            $stmt->execute([$creditId]);
            $credit = $stmt->fetch();

            if (!$credit) {
                throw new Exception("Crédito no encontrado");
            }

            // Eliminar pagos asociados
            $stmt = $db->prepare("DELETE FROM payments WHERE credit_id = ?");
            $stmt->execute([$creditId]);

            // Eliminar el crédito
            $stmt = $db->prepare("DELETE FROM credits WHERE id = ?");
            $stmt->execute([$creditId]);

            $db->commit();
            $_SESSION['success_message'] = "El crédito ha sido eliminado exitosamente.";
            header('Location: index.php');
            exit;

        } catch (Exception $e) {
            $db->rollBack();
            throw $e;
        }
    }

    // Obtener información del crédito para mostrar en la confirmación
    $stmt = $db->prepare("
        SELECT 
            c.*,
            cu.name as customer_name,
            cu.contact as customer_contact,
            (SELECT COUNT(*) FROM payments p WHERE p.credit_id = c.id) as payments_made
        FROM credits c
        JOIN customers cu ON c.customer_id = cu.id
        WHERE c.id = ?
    ");
    $stmt->execute([$creditId]);
    $credit = $stmt->fetch();

    if (!$credit) {
        throw new Exception("Crédito no encontrado");
    }

    $pageTitle = "Eliminar Crédito";
    require_once 'templates/header.php';
?>

<div class="bg-white rounded-lg shadow-md p-6 max-w-2xl mx-auto">
    <div class="flex items-center justify-between mb-6">
        <h1 class="text-2xl font-semibold text-gray-800">
            <i class="fas fa-trash mr-2"></i>Eliminar Crédito
        </h1>
        <a href="index.php" class="text-blue-500 hover:text-blue-600">
            <i class="fas fa-arrow-left mr-1"></i>Volver
        </a>
    </div>

    <div class="bg-red-50 border-l-4 border-red-500 p-4 mb-6">
        <div class="flex">
            <div class="flex-shrink-0">
                <i class="fas fa-exclamation-triangle text-red-500"></i>
            </div>
            <div class="ml-3">
                <h3 class="text-lg font-medium text-red-800">
                    ¿Está seguro que desea eliminar este crédito?
                </h3>
                <p class="mt-2 text-red-700">
                    Esta acción eliminará permanentemente el crédito y todos sus pagos asociados.
                    Esta operación no se puede deshacer.
                </p>
            </div>
        </div>
    </div>

    <!-- Detalles del Crédito -->
    <div class="bg-gray-50 p-4 rounded-lg mb-6">
        <h2 class="text-lg font-medium text-gray-800 mb-4">Detalles del Crédito</h2>
        <div class="grid grid-cols-2 gap-4">
            <div>
                <p class="text-sm text-gray-600">Cliente:</p>
                <p class="font-medium"><?php echo htmlspecialchars($credit['customer_name']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Contacto:</p>
                <p class="font-medium"><?php echo htmlspecialchars($credit['customer_contact']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Monto Total:</p>
                <p class="font-medium"><?php echo formatMoney($credit['total_amount']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Saldo Pendiente:</p>
                <p class="font-medium"><?php echo formatMoney($credit['outstanding_balance']); ?></p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Cuotas:</p>
                <p class="font-medium"><?php echo $credit['payments_made']; ?> de <?php echo $credit['num_installments']; ?> pagadas</p>
            </div>
            <div>
                <p class="text-sm text-gray-600">Fecha de Inicio:</p>
                <p class="font-medium"><?php echo formatDate($credit['start_date']); ?></p>
            </div>
        </div>
    </div>

    <form action="delete_credit.php?id=<?php echo $creditId; ?>" method="POST" class="space-y-4">
        <div class="flex items-center">
            <input type="checkbox" 
                   id="confirm" 
                   name="confirm" 
                   required
                   class="h-4 w-4 text-red-600 focus:ring-red-500 border-gray-300 rounded">
            <label for="confirm" class="ml-2 block text-sm text-gray-900">
                Confirmo que deseo eliminar este crédito y todos sus pagos asociados
            </label>
        </div>

        <div class="flex justify-end space-x-2">
            <a href="index.php" 
               class="px-4 py-2 border border-gray-300 rounded-md text-gray-700 bg-white hover:bg-gray-50 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-blue-500">
                Cancelar
            </a>
            <button type="submit" 
                    name="confirm_delete"
                    value="yes"
                    class="px-4 py-2 border border-transparent rounded-md shadow-sm text-white bg-red-600 hover:bg-red-700 focus:outline-none focus:ring-2 focus:ring-offset-2 focus:ring-red-500"
                    onclick="return confirm('¿Está completamente seguro de eliminar este crédito? Esta acción no se puede deshacer.')">
                <i class="fas fa-trash mr-1"></i> Eliminar Crédito
            </button>
        </div>
    </form>
</div>

<?php
    require_once 'templates/footer.php';
} catch (Exception $e) {
    error_log("Error en delete_credit.php: " . $e->getMessage());
    $errorMessage = "Ha ocurrido un error al procesar la solicitud. Por favor, intente nuevamente.";
    require_once 'templates/header.php';
    echo "<div class='bg-red-100 border-l-4 border-red-500 text-red-700 p-4 mb-4' role='alert'>
            <p class='font-bold'>Error</p>
            <p>$errorMessage</p>
          </div>";
    require_once 'templates/footer.php';
}
?>