<?php
require_once 'config.php';
require_once 'db.php';
require_once 'functions.php';

$creditId = isset($_GET['id']) ? intval($_GET['id']) : 0;

try {
    $db = Database::getInstance()->getConnection();

    $stmt = $db->prepare("SELECT c.*, cu.name, cu.contact FROM credits c JOIN customers cu ON c.customer_id = cu.id WHERE c.id = ?");
    $stmt->execute([$creditId]);
    $credito = $stmt->fetch();

    if (!$credito) {
        echo "Crédito no encontrado.";
        exit;
    }

    $stmt = $db->prepare("SELECT * FROM installments WHERE credit_id = ? ORDER BY installment_number ASC");
    $stmt->execute([$creditId]);
    $cuotas = $stmt->fetchAll();

} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
    exit;
}
?><!DOCTYPE html><html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Detalle de Cuotas</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <script>
        function marcarPagada(id) {
            fetch('marcar_cuota_pagada.php', {
                method: 'POST',
                headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
                body: 'id=' + id
            })
            .then(response => response.text())
            .then(data => {
                if (data.trim() === 'OK') {
                    location.reload();
                } else {
                    alert('Error al marcar como pagada: ' + data);
                }
            });
        }function revertirCuota(id) {
        fetch('revertir_cuota.php', {
            method: 'POST',
            headers: { 'Content-Type': 'application/x-www-form-urlencoded' },
            body: 'id=' + id
        })
        .then(response => response.text())
        .then(data => {
            if (data.trim() === 'OK') {
                location.reload();
            } else {
                alert('Error al revertir cuota: ' + data);
            }
        });
    }
</script>

</head>
<body class="bg-gray-100 p-6">
    <div class="max-w-6xl mx-auto bg-white p-6 rounded shadow">
        <div class="flex justify-between items-center mb-6">
            <h1 class="text-2xl font-bold text-gray-800">
                Detalle del Préstamo #<?php echo $credito['id']; ?>
            </h1>
            <div class="flex gap-2">
                <a href="index.php" class="bg-gray-600 hover:bg-gray-700 text-white px-4 py-2 rounded transition-colors">
                    <i class="fas fa-arrow-left mr-1"></i> Volver
                </a>
                <a href="reporte_cliente_pdf.php?id=<?php echo $credito['id']; ?>" target="_blank" class="bg-blue-600 hover:bg-blue-700 text-white px-4 py-2 rounded transition-colors">
                    <i class="fas fa-file-pdf mr-1"></i> Exportar PDF
                </a>
            </div>
        </div><div class="grid grid-cols-1 md:grid-cols-2 gap-4 mb-6">
        <div>
            <p class="text-sm text-gray-600">Cliente:</p>
            <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['name']); ?></p>
        </div>
        <div>
            <p class="text-sm text-gray-600">Contacto:</p>
            <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['contact']); ?></p>
        </div>
        <div>
            <p class="text-sm text-gray-600">Producto:</p>
            <p class="text-lg font-semibold text-gray-800"><?php echo htmlspecialchars($credito['product']); ?></p>
        </div>
        <div>
            <p class="text-sm text-gray-600">Monto Total:</p>
            <p class="text-lg font-semibold text-gray-800">$<?php echo number_format($credito['total_amount'], 2, ',', '.'); ?></p>
        </div>
    </div>

    <h2 class="text-xl font-semibold text-gray-800 mb-3">Cuotas</h2>
    <div class="overflow-x-auto">
        <table class="min-w-full border border-gray-300 text-sm">
            <thead class="bg-gray-100">
                <tr>
                    <th class="border p-2">#</th>
                    <th class="border p-2">Fecha</th>
                    <th class="border p-2">Monto</th>
                    <th class="border p-2">Pagado</th>
                    <th class="border p-2">Estado</th>
                    <th class="border p-2">Acción</th>
                </tr>
            </thead>
            <tbody>
                <?php foreach ($cuotas as $cuota): ?>
                <tr class="text-center hover:bg-gray-50">
                    <td class="border p-2"><?php echo $cuota['installment_number']; ?></td>
                    <td class="border p-2"><?php echo date('d/m/Y', strtotime($cuota['due_date'])); ?></td>
                    <td class="border p-2">$<?php echo number_format($cuota['amount'], 2, ',', '.'); ?></td>
                    <td class="border p-2">$<?php echo number_format($cuota['amount_paid'], 2, ',', '.'); ?></td>
                    <td class="border p-2">
                        <?php if ($cuota['status'] === 'pagado'): ?>
                            <span class="text-green-600 font-bold">Pagado</span>
                        <?php elseif ($cuota['amount_paid'] > 0): ?>
                            <span class="text-yellow-600 font-bold">Parcial</span>
                        <?php else: ?>
                            <span class="text-red-600 font-bold">Pendiente</span>
                        <?php endif; ?>
                    </td>
                    <td class="border p-2 space-y-1">
                        <a href="registrar_pago.php?id=<?php echo $cuota['id']; ?>" class="inline-block bg-indigo-600 hover:bg-indigo-700 text-white px-2 py-1 rounded text-xs">
                            Registrar Pago
                        </a>
                        <?php if ($cuota['status'] !== 'pagado'): ?>
                            <button onclick="marcarPagada(<?php echo $cuota['id']; ?>)" class="w-full bg-blue-500 hover:bg-blue-600 text-white px-2 py-1 rounded text-xs">
                                Marcar Pagada
                            </button>
                        <?php endif; ?>
                        <button onclick="revertirCuota(<?php echo $cuota['id']; ?>)" class="w-full bg-gray-500 hover:bg-gray-600 text-white px-2 py-1 rounded text-xs">
                            Revertir
                        </button>
                    </td>
                </tr>
                <?php endforeach; ?>
            </tbody>
        </table>
    </div>

    <div class="mt-6 text-center">
        <button onclick="window.print()" class="bg-green-600 hover:bg-green-700 text-white px-4 py-2 rounded">
            Imprimir Cronograma
        </button>
    </div>
</div>

</body>
</html>