<?php
require_once 'config.php';
require_once 'db.php';

$id = isset($_GET['installment_id']) ? intval($_GET['installment_id']) : 0;

try {
    $db = Database::getInstance()->getConnection();

    $stmt = $db->prepare("SELECT i.*, c.product, c.customer_id, cu.name AS cliente, cu.contact 
                          FROM installments i
                          JOIN credits c ON c.id = i.credit_id
                          JOIN customers cu ON cu.id = c.customer_id
                          WHERE i.id = ?");
    $stmt->execute([$id]);
    $cuota = $stmt->fetch();

    if (!$cuota) {
        echo "Cuota no encontrada";
        exit;
    }

    $stmt = $db->prepare("SELECT * FROM payments 
                          WHERE installment_id = ? 
                          ORDER BY id DESC LIMIT 1");
    $stmt->execute([$id]);
    $pago = $stmt->fetch();

    if (!$pago) {
        echo "Pago no encontrado";
        exit;
    }

} catch (Exception $e) {
    echo "Error: " . $e->getMessage();
    exit;
}
?>

<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <title>Recibo de Pago</title>
    <script src="https://cdn.tailwindcss.com"></script>
    <style>
        @media print {
            .no-print { display: none; }
        }
    </style>
</head>
<body class="bg-white p-6 text-sm">
<div class="max-w-xl mx-auto border border-gray-400 rounded p-4">
    <h1 class="text-center text-xl font-bold text-gray-700 mb-4">RECIBO DE PAGO</h1>

    <div class="mb-3">
        <p><strong>Cliente:</strong> <?php echo htmlspecialchars($cuota['cliente']); ?></p>
        <p><strong>DNI / Contacto:</strong> <?php echo htmlspecialchars($cuota['contact']); ?></p>
        <p><strong>Producto:</strong> <?php echo htmlspecialchars($cuota['product']); ?></p>
    </div>

    <div class="mb-3">
        <p><strong>N° de Cuota:</strong> <?php echo $cuota['installment_number']; ?></p>
        <p><strong>Fecha de vencimiento:</strong> <?php echo date('d/m/Y', strtotime($cuota['due_date'])); ?></p>
        <p><strong>Monto total de la cuota:</strong> $<?php echo number_format($cuota['amount'], 2, ',', '.'); ?></p>
        <p><strong>Importe pagado:</strong> $<?php echo number_format($pago['payment_amount'], 2, ',', '.'); ?></p>
        <p><strong>Método de pago:</strong> <?php echo htmlspecialchars($pago['method']); ?></p>
        <p><strong>Fecha del pago:</strong> <?php echo date('d/m/Y', strtotime($pago['payment_date'])); ?></p>
        <?php if (!empty($pago['notes'])): ?>
            <p><strong>Observaciones:</strong> <?php echo htmlspecialchars($pago['notes']); ?></p>
        <?php endif; ?>
    </div>

    <div class="mt-6">
        <p><strong>Saldo acumulado pagado:</strong> $<?php echo number_format($cuota['amount_paid'], 2, ',', '.'); ?></p>
        <p><strong>Estado de la cuota:</strong> <?php echo ucfirst($cuota['status']); ?></p>
    </div>

    <div class="mt-8 flex justify-between">
        <div class="text-center">
            <div class="border-t border-gray-500 pt-2">Firma del Cliente</div>
        </div>
        <div class="text-center">
            <div class="border-t border-gray-500 pt-2">SoloTecno</div>
        </div>
    </div>

    <div class="text-center mt-6 space-y-2 no-print">
        <button onclick="window.print()" class="bg-blue-600 text-white px-4 py-2 rounded hover:bg-blue-700">
            Imprimir Recibo
        </button>

        <a href="recibo_pdf.php?installment_id=<?php echo $id; ?>" target="_blank"
           class="bg-green-600 text-white px-4 py-2 rounded hover:bg-green-700 inline-block">
            Ver / Descargar PDF
        </a>

        <a href="https://wa.me/?text=Hola!%20Te%20envío%20el%20recibo%20de%20tu%20pago:%20<?php echo urlencode('https://' . $_SERVER['HTTP_HOST'] . '/creditos/recibo_pdf.php?installment_id=' . $id); ?>"
           target="_blank"
           class="bg-emerald-600 text-white px-4 py-2 rounded hover:bg-emerald-700 inline-block">
            Enviar por WhatsApp
        </a>
    </div>
</div>
</body>
</html>
