<?php
require_once 'config.php';
require_once 'db.php';

$id = isset($_GET['id']) ? intval($_GET['id']) : 0;

$db = Database::getInstance()->getConnection();
$stmt = $db->prepare("SELECT i.*, c.product, cu.name FROM installments i
                      JOIN credits c ON c.id = i.credit_id
                      JOIN customers cu ON cu.id = c.customer_id
                      WHERE i.id = ?");
$stmt->execute([$id]);
$cuota = $stmt->fetch();

if (!$cuota) {
    echo "Cuota no encontrada";
    exit;
}
?>

<!DOCTYPE html>
<html lang='es'>
<head>
  <meta charset='UTF-8'>
  <title>Registrar Pago</title>
  <script src='https://cdn.tailwindcss.com'></script>
</head>
<body class='bg-gray-100 p-6'>
<div class='max-w-xl mx-auto bg-white p-6 rounded shadow'>
    <h1 class='text-xl font-bold mb-4'>Registrar Pago - Cuota #<?php echo $cuota['installment_number']; ?></h1>
    <p><strong>Cliente:</strong> <?php echo htmlspecialchars($cuota['name']); ?></p>
    <p><strong>Producto:</strong> <?php echo htmlspecialchars($cuota['product']); ?></p>
    <p><strong>Fecha de vencimiento:</strong> <?php echo $cuota['due_date']; ?></p>
    <p><strong>Monto:</strong> $<?php echo number_format($cuota['amount'], 2, ',', '.'); ?></p>
    <p><strong>Pagado hasta ahora:</strong> $<?php echo number_format($cuota['amount_paid'], 2, ',', '.'); ?></p>

    <form action='procesar_pago.php' method='POST' class='mt-4 space-y-4'>
        <input type='hidden' name='id' value='<?php echo $cuota['id']; ?>'>
        <div>
            <label class='block mb-1'>Monto a abonar ($)</label>
            <input type='number' name='amount' step='0.01' min='0' required class='w-full p-2 border rounded'>
        </div>
        <div>
            <label class='block mb-1'>Método de pago</label>
            <input type='text' name='method' placeholder='Ej: Efectivo, Transferencia' required class='w-full p-2 border rounded'>
        </div>
        <div>
            <label class='block mb-1'>Observaciones</label>
            <textarea name='notes' rows='2' class='w-full p-2 border rounded'></textarea>
        </div>
        <div class='text-center'>
            <button type='submit' class='bg-blue-600 text-white px-6 py-2 rounded hover:bg-blue-700'>Guardar Pago</button>
        </div>
    </form>
</div>
</body>
</html>
