<?php
require_once 'config.php';
require_once 'db.php';

$db = Database::getInstance()->getConnection();

$stmt = $db->query("SELECT i.*, i.id as installment_id, c.product, cu.name, cu.contact
                    FROM installments i
                    JOIN credits c ON c.id = i.credit_id
                    JOIN customers cu ON cu.id = c.customer_id
                    WHERE i.status != 'pagado' AND i.due_date < CURDATE()
                    ORDER BY i.due_date ASC");
$cuotas = $stmt->fetchAll();
?>

<!DOCTYPE html>
<html lang='es'>
<head>
  <meta charset='UTF-8'>
  <title>Cuotas Vencidas</title>
  <script src='https://cdn.tailwindcss.com'></script>
</head>
<body class='bg-gray-100 p-6'>
<div class='max-w-6xl mx-auto bg-white p-6 rounded shadow'>
    <div class='flex justify-between items-center mb-4'>
        <h1 class='text-2xl font-bold'>Reporte de Cuotas Vencidas</h1>
        <button onclick='window.print()' class='bg-green-600 text-white px-4 py-2 rounded hover:bg-green-700'>Imprimir</button>
    </div>

    <table class='w-full border border-gray-300 text-sm'>
        <thead class='bg-gray-200'>
            <tr>
                <th class='border p-2'>Cliente</th>
                <th class='border p-2'>Contacto</th>
                <th class='border p-2'>Producto</th>
                <th class='border p-2'>Cuota #</th>
                <th class='border p-2'>Vencimiento</th>
                <th class='border p-2'>Monto</th>
                <th class='border p-2'>Pagado</th>
                <th class='border p-2'>Estado</th>
                <th class='border p-2'>Días atraso</th>
            </tr>
        </thead>
        <tbody>
            <?php foreach ($cuotas as $c): 
                $atraso = (new DateTime())->diff(new DateTime($c['due_date']))->days;
            ?>
            <tr class='text-center'>
                <td class='border p-2'><?php echo htmlspecialchars($c['name']); ?></td>
                <td class='border p-2'><?php echo htmlspecialchars($c['contact']); ?></td>
                <td class='border p-2'><?php echo htmlspecialchars($c['product']); ?></td>
                <td class='border p-2'><?php echo $c['installment_number']; ?></td>
                <td class='border p-2 text-red-600'><?php echo date('d/m/Y', strtotime($c['due_date'])); ?></td>
                <td class='border p-2'>$<?php echo number_format($c['amount'], 2, ',', '.'); ?></td>
                <td class='border p-2'>$<?php echo number_format($c['amount_paid'], 2, ',', '.'); ?></td>
                <td class='border p-2'>
                    <?php if ($c['status'] === 'parcial'): ?>
                        <span class='text-yellow-600 font-semibold'>Parcial</span>
                    <?php else: ?>
                        <span class='text-red-600 font-semibold'>Pendiente</span>
                    <?php endif; ?>
                </td>
                <td class='border p-2 text-sm'><?php echo $atraso; ?></td>
            </tr>
            <?php endforeach; ?>
        </tbody>
    </table>

    <?php if (empty($cuotas)): ?>
        <p class='text-center text-gray-500 mt-6'>No hay cuotas vencidas hasta la fecha.</p>
    <?php endif; ?>
</div>
</body>
</html>
